Update of /cvsroot/tmda/tmda/TMDA
In directory usw-pr-cvs1:/tmp/cvs-serv2511/TMDA
Modified Files:
Defaults.py
Log Message:
Add code from Tim Legant to auto-generate HTML (config-vars.html) from
the variable comments in Defaults.py.
Index: Defaults.py
===================================================================
RCS file: /cvsroot/tmda/tmda/TMDA/Defaults.py,v
retrieving revision 1.144
retrieving revision 1.145
diff -u -r1.144 -r1.145
--- Defaults.py 30 Sep 2002 19:16:43 -0000 1.144
+++ Defaults.py 1 Oct 2002 19:55:32 -0000 1.145
@@ -19,13 +19,15 @@
# along with TMDA; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-"""TMDA configuration variable defaults."""
+"""TMDA configuration variable defaults.
+See http://tmda.net/config-vars.html for an HTMLized version of the
+information below.
+"""
-# NEVER make configuration changes to this file. ALWAYS make them in
-# /etc/tmdarc or ~/.tmdarc instead. Settings in ~/.tmdarc override
-# those in /etc/tmdarc.
+# NEVER make configuration changes to this file. ALWAYS make them in
+# /etc/tmdarc or ~/.tmda/config instead.
import binascii
import os
_______________________________________
tmda-cvs mailing list
http://tmda.net/lists/listinfo/tmda-cvs